package com.mojang.ld22.level.tile;

import com.mojang.ld22.entity.Entity;
import com.mojang.ld22.entity.ItemEntity;
import com.mojang.ld22.entity.Player;
import com.mojang.ld22.entity.particle.SmashParticle;
import com.mojang.ld22.entity.particle.TextParticle;
import com.mojang.ld22.gfx.Color;
import com.mojang.ld22.gfx.Screen;
import com.mojang.ld22.item.Item;
import com.mojang.ld22.item.ResourceItem;
import com.mojang.ld22.item.ToolItem;
import com.mojang.ld22.item.ToolType;
import com.mojang.ld22.item.resource.Resource;
import com.mojang.ld22.level.Level;
// import com.mojang.ld22.sound.Sound;

public class HoleTile extends Tile {
	public HoleTile(int id) {
		super(id);
		connectsToSand = true;
		connectsToWater = true;
		connectsToLava= true;
	}

	public void render(Screen screen, Level level, int x, int y) {
		int col = Color.get(111, 111, 110, 110);
		int transitionColor1 = Color.get(3, 111, level.dirtColor - 111, level.dirtColor);
		int transitionColor2 = Color.get(3, 111, level.sandColor - 110, level.sandColor);

		boolean u = !level.getTile(x, y - 1).connectsToLiquid();
		boolean d = !level.getTile(x, y + 1).connectsToLiquid();
		boolean l = !level.getTile(x - 1, y).connectsToLiquid();
		boolean r = !level.getTile(x + 1, y).connectsToLiquid();

		boolean su = u && level.getTile(x, y - 1).connectsToSand;
		boolean sd = d && level.getTile(x, y + 1).connectsToSand;
		boolean sl = l && level.getTile(x - 1, y).connectsToSand;
		boolean sr = r && level.getTile(x + 1, y).connectsToSand;

		if (!u && !l) {
			screen.render(x * 16 + 0, y * 16 + 0, 0, col, 0);
		} else
			screen.render(x * 16 + 0, y * 16 + 0, (l ? 14 : 15) + (u ? 0 : 1) * 32, (su || sl) ? transitionColor2 : transitionColor1, 0);

		if (!u && !r) {
			screen.render(x * 16 + 8, y * 16 + 0, 1, col, 0);
		} else
			screen.render(x * 16 + 8, y * 16 + 0, (r ? 16 : 15) + (u ? 0 : 1) * 32, (su || sr) ? transitionColor2 : transitionColor1, 0);

		if (!d && !l) {
			screen.render(x * 16 + 0, y * 16 + 8, 2, col, 0);
		} else
			screen.render(x * 16 + 0, y * 16 + 8, (l ? 14 : 15) + (d ? 2 : 1) * 32, (sd || sl) ? transitionColor2 : transitionColor1, 0);
		if (!d && !r) {
			screen.render(x * 16 + 8, y * 16 + 8, 3, col, 0);
		} else
			screen.render(x * 16 + 8, y * 16 + 8, (r ? 16 : 15) + (d ? 2 : 1) * 32, (sd || sr) ? transitionColor2 : transitionColor1, 0);
	}
// Stairs Experiment.  Dig hole to next level.

	public boolean interact(Level level, int xt, int yt, Player player, Item item, int attackDir) {
		if (item instanceof ToolItem) {
			ToolItem tool = (ToolItem) item;
			if (tool.type == ToolType.pickaxe) {
				if (player.payStamina(4 - tool.level)) {
					hurt(level, xt, yt, random.nextInt(10) + (tool.level) * 5 + 10);
					return true;
				}
			}
		}
		return false;
	}

	public void hurt(Level level, int x, int y, int dmg) {
		int damage = level.getData(x, y) + dmg;
		level.add(new SmashParticle(x * 16 + 8, y * 16 + 8));
		level.add(new TextParticle("" + dmg, x * 16 + 8, y * 16 + 8, Color.get(-1, 500, 500, 500)));
		
			int count = random.nextInt(5) + 1;  
			if (count == 4) {
				level.add(new ItemEntity(new ResourceItem(Resource.stone), x * 16 + random.nextInt(10) + 3, y * 16 + random.nextInt(10) + 3));
			}
			
			count = random.nextInt(2) + 1;  
			if (count == 1) {
				level.add(new ItemEntity(new ResourceItem(Resource.dirt), x * 16 + random.nextInt(10) + 3, y * 16 + random.nextInt(10) + 3));
			}
			count = random.nextInt(5) + 1;  
			if (count == 4) {
				level.add(new ItemEntity(new ResourceItem(Resource.coal), x * 16 + random.nextInt(10) + 3, y * 16 + random.nextInt(10) + 3));
			}
			count = random.nextInt(10) + 1;  
			if (count == 4) {
				level.add(new ItemEntity(new ResourceItem(Resource.ironOre), x * 16 + random.nextInt(10) + 3, y * 16 + random.nextInt(10) + 3));
			}

			count = random.nextInt(15) + 1;  
			if (count == 4) {
				level.add(new ItemEntity(new ResourceItem(Resource.goldOre), x * 16 + random.nextInt(10) + 3, y * 16 + random.nextInt(10) + 3));
			}

			count = random.nextInt(20) + 1;  
			if (count == 4) {
				level.add(new ItemEntity(new ResourceItem(Resource.gem), x * 16 + random.nextInt(10) + 3, y * 16 + random.nextInt(10) + 3));
			}

			if (damage >= 50) {
			level.setTile(x, y, Tile.stairsDown, 0);
		} else {
			level.setData(x, y, damage);}
		}
	
	
//	public boolean interact(Level level, int xt, int yt, Player player, Item item, int attackDir) {
	//	if (item instanceof ToolItem) {
		//	ToolItem tool = (ToolItem) item;
		//	if (tool.type == ToolType.shovel) {
		//		if (player.payStamina(4 - tool.level)) {
		//			level.setTile(xt, yt, Tile.stairsDown, 0);
		//			level.add(new ItemEntity(new ResourceItem(Resource.dirt), xt * 16 + random.nextInt(10) + 3, yt * 16 + random.nextInt(10) + 3));
		//			Sound.monsterHurt.play();
		//			return true;
		//		}
		//	}
	//	}
	//	return false;
//	}
	
// End stairs experiment	
	public boolean mayPass(Level level, int x, int y, Entity e) {
		return e.canDig();
	}

}
