package com.mojang.ld22.screen;

import com.mojang.ld22.gfx.Color;
import com.mojang.ld22.gfx.Font;
import com.mojang.ld22.gfx.Screen;
import com.mojang.ld22.sound.Sound;

public class TitleMenu extends Menu {
	private int selected = 0;

	private static final String[] options = { "Start game", "How to play", "About", "Some Details", "More Details" };

	public TitleMenu() {
	}

	public void tick() {
		if (input.up.clicked) selected--;
		if (input.down.clicked) selected++;

		int len = options.length;
		if (selected < 0) selected += len;
		if (selected >= len) selected -= len;

		if (input.attack.clicked || input.menu.clicked) {
			if (selected == 0) {
				Sound.test.play();
				game.resetGame();
				game.setMenu(null);
			}
			if (selected == 1) game.setMenu(new InstructionsMenu(this));
			if (selected == 2) game.setMenu(new AboutMenu(this));
			if (selected == 3) game.setMenu(new DetailsMenu(this));
			if (selected == 4) game.setMenu(new MoreDetailsMenu(this));
		}
	}

	public void render(Screen screen) {
		screen.clear(0);

		int h = 2;
		int w = 15; //Length of Title
		int titleColor = Color.get(0, 010, 131, 551);
		int xo = (screen.w - w * 8) / 2;
		int yo = 24;
		for (int y = 0; y < h; y++) {
			for (int x = 0; x < w; x++) {
				screen.render(xo + x * 8, yo + y * 8, x + (y + 6) * 32, titleColor, 0);
			}
		}
		
		// Display Version
		Font.draw("Version 7", screen, (screen.w - 9 * 8) / 2, 6 * 8, Color.get(0, 111, 111, 111));
		Font.draw("Ships Ahoy!", screen, (screen.w - 11 * 8) / 2, 7 * 8, Color.get(0, 111, 111, 111));
		
		//Font.draw("Eating fungus makes you glow!", screen, (screen.w - 26 * 8) / 2, 14 * 8, Color.get(0, 111, 111, 111));
		//Font.draw("nut or shroom,the game will lock up.", screen, (screen.w - 35 * 8) / 2, 15 * 8, Color.get(0, 111, 111, 111));
		//Font.draw("When a cone is defined, the target", screen, (screen.w - 35 * 8) / 2, 16 * 8, Color.get(0, 111, 111, 111));
		//Font.draw("resource value is null.That is what", screen, (screen.w - 35 * 8) / 2, 17 * 8, Color.get(0, 111, 111, 111));
		//Font.draw("causes it to lock.", screen, (screen.w - 35 * 8) / 2, 18 * 8, Color.get(0, 111, 111, 111));
		// Font.draw("Text Message", screen, (screen.w - L * 8) / 2, C * 8, Color.get(0, 111, 111, 111)); //
		// L is how long the message is. C is how far down to print.

		for (int i = 0; i < 5; i++) {
			String msg = options[i];
			int col = Color.get(0, 222, 222, 222);
			if (i == selected) {
				msg = "> " + msg + " <";
				col = Color.get(0, 555, 555, 555);
			}
			Font.draw(msg, screen, (screen.w - msg.length() * 8) / 2, (10 + i) * 8, col);
		}

		Font.draw("(Arrow keys,X and C)", screen, 0, screen.h - 8, Color.get(0, 111, 111, 111));
		
	}
}